MoonWidget class

Inheritance

Constructors

MoonWidget({Key? key, required DateTime date, double size = 36, double resolution = 96, Color moonColor = Colors.amber, Color earthshineColor = Colors.black87})
const

Properties

date → DateTime
DateTime to show. Even hour, minutes, and seconds are calculated for MoonWidget
final
earthshineColor → Color
Color of dark side of moon
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
moonColor → Color
Color of light side of moon
final
resolution → double
Resolution will be the moon radius. Large resolution needs more math operation makes widget heavy. Enter a small number if it is sufficient to mark it small, such as an icon or marker.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
Decide the container size for the MoonWidget
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited